---
title: fns
---

# `marvin.fns`

## Submodules
- [`cast`](marvin-fns-cast)
- [`classify`](marvin-fns-classify)
- [`extract`](marvin-fns-extract)
- [`fn`](marvin-fns-fn)
- [`generate`](marvin-fns-generate)
- [`plan`](marvin-fns-plan)
- [`run`](marvin-fns-run)
- [`say`](marvin-fns-say)
- [`summarize`](marvin-fns-summarize)

---

**Parent Module:** [`marvin`](marvin)
